Skip to contents

Returns one row per (grid_row, stage) with planned action:

  • execute

  • reuse (artifact already exists and sink overwrite policy is skip)

  • blocked

Usage

flow_plan(fl, limit = NULL)

Arguments

fl

A flow() object.

limit

Optional limit on number of grid rows to plan.

Value

A tibble plan with reason codes and stage fingerprints.