Read a stage's completion manifest
completion_manifest.RdReturns the completion manifest for a stage as a tibble. Each row represents a previously completed execution with its parameter values and output paths.
completion_manifest.RdReturns the completion manifest for a stage as a tibble. Each row represents a previously completed execution with its parameter values and output paths.